import { EventEmitter, Output, Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from './type';
import { TimeAxisLabelFormatCollection } from './igx-time-axis-label-format-collection';
import { AxisRangeChangedEventArgs } from './igx-axis-range-changed-event-args';
import { IgxCategoryXAxisComponent } from './igx-category-x-axis-component';
import { IgxCategoryAxisBaseComponent } from './igx-category-axis-base-component';
import { IgxAxisComponent } from './igx-axis-component';
import { OrdinalTimeXAxis } from "./OrdinalTimeXAxis";
import { TimeAxisLabelFormatCollection as TimeAxisLabelFormatCollection_internal } from "./TimeAxisLabelFormatCollection";
import { TimeAxisLabelFormat } from "./TimeAxisLabelFormat";
import { SyncableObservableCollection$1 } from "./SyncableObservableCollection$1";
/**
 * A horizontal axis that uses an ordinal DateTime scale.
 * On an ordinal time axis, datapoints are aligned according to their order in the ItemsSource, like a category axis.
*
* You can use the `OrdinalTimeXAxis` to display dates at equidistant.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
* 		dateTimeMemberPath="date"
* 		#xAxis>
*     </igx-ordinal-time-x-axis>
* </igx-data-chart>
* ```
*/
export const IgxOrdinalTimeXAxisComponent_PROVIDERS = [{ provide: IgxCategoryXAxisComponent, useExisting: forwardRef(() => IgxOrdinalTimeXAxisComponent) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxOrdinalTimeXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxOrdinalTimeXAxisComponent) }];
export class IgxOrdinalTimeXAxisComponent extends IgxCategoryXAxisComponent {
    constructor() {
        super();
        this._labelFormats = null;
        this._actualRangeChanged = null;
    }
    createImplementation() {
        return new OrdinalTimeXAxis();
    }
    get i() {
        return this._implementation;
    }
    get dateTimeMemberPath() {
        return this.i.la;
    }
    set dateTimeMemberPath(v) {
        this.i.la = v;
    }
    /**
         * A list of axis label formats to apply, which are selected according to the visible axis range.
         * The label format selected will be the one with the largest range smaller than the visible range of the axis.
        *
        * You can use the `LabelFormats` for adjusting the labels depending on the range of the time shown by the chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        * 	<igx-ordinal-time-x-axis
        * 		[labelFormats]="labelFormats"
        * 		dateTimeMemberPath="time"
        * 		#xAxis>
        *     </igx-ordinal-time-x-axis>
        * </igx-data-chart>
        * ```
        */
    get labelFormats() {
        if (this._labelFormats === null) {
            let coll = new TimeAxisLabelFormatCollection();
            let innerColl = this.i.kx;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new TimeAxisLabelFormatCollection_internal();
            }
            this._labelFormats = coll._fromInner(innerColl);
        }
        return this._labelFormats;
    }
    set labelFormats(v) {
        if (this._labelFormats !== null) {
            this._labelFormats._setSyncTarget(null);
            this._labelFormats = null;
        }
        let coll = new TimeAxisLabelFormatCollection();
        this._labelFormats = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(TimeAxisLabelFormat.$type);
        let innerColl = this.i.kx;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new TimeAxisLabelFormatCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._labelFormats._setSyncTarget(syncColl);
    }
    get actualRangeChanged() {
        if (this._actualRangeChanged == null) {
            this._actualRangeChanged = new EventEmitter();
            this.i.actualRangeChanged = delegateCombine(this.i.actualRangeChanged, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new AxisRangeChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    this._actualRangeChanged.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._actualRangeChanged;
    }
}
IgxOrdinalTimeXAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-ordinal-time-x-axis',
                template: ``,
                providers: [{ provide: IgxCategoryXAxisComponent, useExisting: forwardRef(() => IgxOrdinalTimeXAxisComponent) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxOrdinalTimeXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxOrdinalTimeXAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxOrdinalTimeXAxisComponent.ctorParameters = () => [];
IgxOrdinalTimeXAxisComponent.propDecorators = {
    "dateTimeMemberPath": [{ type: Input },],
    "labelFormats": [{ type: Input },],
    "actualRangeChanged": [{ type: Output },],
};
//# sourceMappingURL=igx-ordinal-time-x-axis-component.js.map